declare abstract class ApiClient {
    abstract get authHeaders(): HeadersInit;
    abstract get baseUrl(): string;
    private makeRequest;
    buildUrl(path: string): string;
    get(path: string, params: Omit<RequestInit, "method">): Promise<Response>;
    post(path: string, params: Omit<RequestInit, "method">): Promise<Response>;
    put(path: string, params: Omit<RequestInit, "method">): Promise<Response>;
    delete(path: string, params: Omit<RequestInit, "method">): Promise<Response>;
    patch(path: string, params: Omit<RequestInit, "method">): Promise<Response>;
    static normalizePath(path: string): string;
}

declare const APIKeyUsageOriginPrefix: {
    readonly CLIENT: "ck";
    readonly SERVER: "sk";
};
type APIKeyUsageOriginPrefix = (typeof APIKeyUsageOriginPrefix)[keyof typeof APIKeyUsageOriginPrefix];
declare const APIKeyEnvironmentPrefix: {
    readonly DEVELOPMENT: "development";
    readonly STAGING: "staging";
    readonly PRODUCTION: "production";
};
type APIKeyEnvironmentPrefix = (typeof APIKeyEnvironmentPrefix)[keyof typeof APIKeyEnvironmentPrefix];
type APIKeyPrefix = `${APIKeyUsageOriginPrefix}_${APIKeyEnvironmentPrefix}`;
declare const APIKeyUsageOrigin: {
    readonly CLIENT: "client";
    readonly SERVER: "server";
};
type APIKeyUsageOrigin = (typeof APIKeyUsageOrigin)[keyof typeof APIKeyUsageOrigin];

type ValidateAPIKeyPrefixResult = ValidateAPIKeyPrefixSuccessResult | ValidateAPIKeyFailResult;
type ValidateAPIKeyPrefixSuccessResult = {
    isValid: true;
} & ValidateAPIKeyPrefixSuccessData;
type ValidateAPIKeyFailResult = {
    isValid: false;
    message: string;
};
type ValidateAPIKeyPrefixSuccessData = {
    usageOrigin: APIKeyUsageOrigin;
    environment: APIKeyEnvironmentPrefix;
    prefix: APIKeyPrefix;
};
type ValidateAPIKeyPrefixExpectations = {
    usageOrigin?: APIKeyUsageOrigin;
    environment?: APIKeyEnvironmentPrefix;
};
declare function validateAPIKeyPrefix(apiKey: string, expectations?: ValidateAPIKeyPrefixExpectations): ValidateAPIKeyPrefixResult;
declare function getEnvironmentForKey(apiKey: string): APIKeyEnvironmentPrefix | null;

type ValidateAPIKeyResult = ValidateApiKeySuccessResult | ValidateAPIKeyFailResult;
type ValidateApiKeySuccessResult = {
    isValid: true;
} & ValidateApiKeySuccessData;
type ValidateApiKeySuccessData = ValidateAPIKeyPrefixSuccessData & {
    projectId: string;
};
declare function validateAPIKey(apiKey: string, expectations?: ValidateAPIKeyPrefixExpectations): ValidateAPIKeyResult;

declare const CROSSMINT_API_KEY_SIGNER_PUBLICKEY_STAGING = "3hSfN4dWSwgCg1uf2yytBtK6KxK3ySFKasd2h9J2vSK5";
declare const CROSSMINT_API_KEY_SIGNER_PUBLICKEY_PROD = "8erZh8YApGck3iUSUHqATBxqMTM1Ukp9mHmvGgUWHtkK";

declare function environmentToCrossmintBaseURL(environment: APIKeyEnvironmentPrefix, customMap?: Partial<Record<APIKeyEnvironmentPrefix, string>>): string;

declare function environmentToExpectedPublicKey(environment?: APIKeyEnvironmentPrefix): string | null;

declare function usageOriginToPrefix(usageOrigin: APIKeyUsageOrigin): APIKeyUsageOriginPrefix;

type Crossmint = {
    apiKey: string;
    jwt?: string;
    overrideBaseUrl?: string;
};
declare function createCrossmint(config: Crossmint, apiKeyExpectations?: ValidateAPIKeyPrefixExpectations): Crossmint;

type CrossmintApiClientInternalConfig = {
    sdkMetadata: {
        name: string;
        version: string;
    };
    apiKeyExpectations?: ValidateAPIKeyPrefixExpectations;
};
declare class CrossmintApiClient extends ApiClient {
    crossmint: Crossmint;
    protected parsedAPIKey: ValidateApiKeySuccessResult;
    protected internalConfig: CrossmintApiClientInternalConfig;
    constructor(crossmint: Crossmint, { internalConfig, }: {
        internalConfig: CrossmintApiClientInternalConfig;
    });
    get baseUrl(): string;
    get authHeaders(): {
        Authorization?: string | undefined;
        "x-api-key": string;
    };
}

interface UiConfigColors {
    inputBackground?: string;
    buttonBackground?: string;
    textPrimary?: string;
    textSecondary?: string;
    accent?: string;
    background?: string;
    backgroundSecondary?: string;
    backgroundTertiary?: string;
    border?: string;
    danger?: string;
    textLink?: string;
}
interface UIConfig {
    colors?: UiConfigColors;
    fontSizeBase?: string;
    spacingUnit?: string;
    borderRadius?: string;
    fontWeightPrimary?: string;
    fontWeightSecondary?: string;
    fonts?: UiConfigFonts;
    hideCardForm?: boolean;
}
type UiConfigFonts = (CssFontSource | CustomFontSource)[];
interface CssFontSource {
    cssSrc: string;
    family: string;
}
interface CustomFontSource {
    family: string;
    src: string;
    display?: string;
    style?: "normal" | "italic" | "oblique";
    weight?: string;
}

interface CommonProps {
    uiConfig?: UIConfig;
    environment?: string;
}
interface NFTCollectionViewProps extends CommonProps {
    wallets: Wallet[];
}
interface NFTDetailProps extends CommonProps {
    nft: NFTOrNFTLocator;
}

type UserIdentifierParams = {
    email?: string;
    userId?: string;
    phoneNumber?: string;
};
type UserIdentifier = {
    type: "whiteLabel";
    userId: string;
} | {
    type: "email";
    email: string;
} | {
    type: "phoneNumber";
    phoneNumber: string;
};

type ObjectValues<T extends object> = T[keyof T];
declare function objectValues<T extends object>(obj: T): ReadonlyArray<T[keyof T]>;

declare const BlockchainBaseLayer: {
    readonly EVM: "evm";
    readonly SOLANA: "solana";
    readonly CARDANO: "cardano";
    readonly SUI: "sui";
    readonly APTOS: "aptos";
};
type BlockchainBaseLayer = ObjectValues<typeof BlockchainBaseLayer>;
declare const BLOCKCHAIN_BASE_LAYERS: readonly ("solana" | "cardano" | "evm" | "sui" | "aptos")[];

declare const EVMBlockchain: {
    readonly ETHEREUM: "ethereum";
    readonly POLYGON: "polygon";
    readonly BSC: "bsc";
    readonly OPTIMISM: "optimism";
    readonly ARBITRUM: "arbitrum";
    readonly BASE: "base";
    readonly ZORA: "zora";
    readonly ARBITRUMNOVA: "arbitrumnova";
    readonly ZKATANA: "zkatana";
    readonly ZKYOTO: "zkyoto";
    readonly ASTAR_ZKEVM: "astar-zkevm";
    readonly APEX: "apex";
};
type EVMBlockchain = ObjectValues<typeof EVMBlockchain>;
declare const EVM_CHAINS: readonly ("ethereum" | "polygon" | "bsc" | "optimism" | "arbitrum" | "base" | "zora" | "arbitrumnova" | "zkatana" | "zkyoto" | "astar-zkevm" | "apex")[];
declare const EVMBlockchainTestnet: {
    readonly ARBITRUM_SEPOLIA: "arbitrum-sepolia";
    readonly BASE_GOERLI: "base-goerli";
    readonly BASE_SEPOLIA: "base-sepolia";
    readonly BSC_TESTNET: "bsc-testnet";
    readonly ETHEREUM_GOERLI: "ethereum-goerli";
    readonly ETHEREUM_SEPOLIA: "ethereum-sepolia";
    readonly POLYGON_MUMBAI: "polygon-mumbai";
    readonly POLYGON_AMOY: "polygon-amoy";
    readonly OPTIMISM_GOERLI: "optimism-goerli";
    readonly OPTIMISM_SEPOLIA: "optimism-sepolia";
    readonly ZORA_GOERLI: "zora-goerli";
    readonly ZORA_SEPOLIA: "zora-sepolia";
    readonly HYPERSONIC_TESTNET: "hypersonic-testnet";
};
type EVMBlockchainTestnet = ObjectValues<typeof EVMBlockchainTestnet>;
declare const EVM_BLOCKCHAIN_TESTNETS: readonly ("arbitrum-sepolia" | "base-goerli" | "base-sepolia" | "bsc-testnet" | "ethereum-goerli" | "ethereum-sepolia" | "polygon-mumbai" | "polygon-amoy" | "optimism-goerli" | "optimism-sepolia" | "zora-goerli" | "zora-sepolia" | "hypersonic-testnet")[];
declare const EVMBlockchainIncludingTestnet: {
    readonly ARBITRUM_SEPOLIA: "arbitrum-sepolia";
    readonly BASE_GOERLI: "base-goerli";
    readonly BASE_SEPOLIA: "base-sepolia";
    readonly BSC_TESTNET: "bsc-testnet";
    readonly ETHEREUM_GOERLI: "ethereum-goerli";
    readonly ETHEREUM_SEPOLIA: "ethereum-sepolia";
    readonly POLYGON_MUMBAI: "polygon-mumbai";
    readonly POLYGON_AMOY: "polygon-amoy";
    readonly OPTIMISM_GOERLI: "optimism-goerli";
    readonly OPTIMISM_SEPOLIA: "optimism-sepolia";
    readonly ZORA_GOERLI: "zora-goerli";
    readonly ZORA_SEPOLIA: "zora-sepolia";
    readonly HYPERSONIC_TESTNET: "hypersonic-testnet";
    readonly ETHEREUM: "ethereum";
    readonly POLYGON: "polygon";
    readonly BSC: "bsc";
    readonly OPTIMISM: "optimism";
    readonly ARBITRUM: "arbitrum";
    readonly BASE: "base";
    readonly ZORA: "zora";
    readonly ARBITRUMNOVA: "arbitrumnova";
    readonly ZKATANA: "zkatana";
    readonly ZKYOTO: "zkyoto";
    readonly ASTAR_ZKEVM: "astar-zkevm";
    readonly APEX: "apex";
};
type EVMBlockchainIncludingTestnet = ObjectValues<typeof EVMBlockchainIncludingTestnet>;
declare const EVM_BLOCKCHAINS_INCLUDING_TESTNETS: readonly ("ethereum" | "polygon" | "bsc" | "optimism" | "arbitrum" | "base" | "zora" | "arbitrumnova" | "zkatana" | "zkyoto" | "astar-zkevm" | "apex" | "arbitrum-sepolia" | "base-goerli" | "base-sepolia" | "bsc-testnet" | "ethereum-goerli" | "ethereum-sepolia" | "polygon-mumbai" | "polygon-amoy" | "optimism-goerli" | "optimism-sepolia" | "zora-goerli" | "zora-sepolia" | "hypersonic-testnet")[];

interface EVMNFT {
    chain: EVMBlockchainIncludingTestnet;
    contractAddress: string;
    tokenId: string;
}
interface SolanaNFT {
    mintHash: string;
    chain: "solana";
}
interface CardanoNFT {
    chain: "cardano";
    assetId: string;
}
type NFTLocator<T extends Blockchain> = `${T}:${string}${T extends EVMBlockchainIncludingTestnet ? `:${string}` : ""}`;
type NFT = SolanaNFT | EVMNFT | CardanoNFT;
type NFTOrNFTLocator = NFT | NFTLocator<"solana"> | NFTLocator<"ethereum"> | NFTLocator<"polygon"> | NFTLocator<"bsc"> | NFTLocator<"cardano">;

interface Wallet {
    chain: string;
    publicKey: string;
}

declare const Blockchain: {
    readonly ETHEREUM: "ethereum";
    readonly POLYGON: "polygon";
    readonly BSC: "bsc";
    readonly OPTIMISM: "optimism";
    readonly ARBITRUM: "arbitrum";
    readonly BASE: "base";
    readonly ZORA: "zora";
    readonly ARBITRUMNOVA: "arbitrumnova";
    readonly ZKATANA: "zkatana";
    readonly ZKYOTO: "zkyoto";
    readonly ASTAR_ZKEVM: "astar-zkevm";
    readonly APEX: "apex";
    readonly SOLANA: "solana";
    readonly CARDANO: "cardano";
    readonly SUI: "sui";
    readonly APTOS: "aptos";
};
type Blockchain = ObjectValues<typeof Blockchain>;
declare const BLOCKCHAINS: readonly ("ethereum" | "polygon" | "bsc" | "optimism" | "arbitrum" | "base" | "zora" | "arbitrumnova" | "zkatana" | "zkyoto" | "astar-zkevm" | "apex" | "solana" | "cardano" | "sui" | "aptos")[];
declare const BlockchainTestnet: {
    readonly ARBITRUM_SEPOLIA: "arbitrum-sepolia";
    readonly BASE_GOERLI: "base-goerli";
    readonly BASE_SEPOLIA: "base-sepolia";
    readonly BSC_TESTNET: "bsc-testnet";
    readonly ETHEREUM_GOERLI: "ethereum-goerli";
    readonly ETHEREUM_SEPOLIA: "ethereum-sepolia";
    readonly POLYGON_MUMBAI: "polygon-mumbai";
    readonly POLYGON_AMOY: "polygon-amoy";
    readonly OPTIMISM_GOERLI: "optimism-goerli";
    readonly OPTIMISM_SEPOLIA: "optimism-sepolia";
    readonly ZORA_GOERLI: "zora-goerli";
    readonly ZORA_SEPOLIA: "zora-sepolia";
    readonly HYPERSONIC_TESTNET: "hypersonic-testnet";
};
type BlockchainTestnet = ObjectValues<typeof BlockchainTestnet>;
declare const BLOCKCHAIN_TESTNETS: readonly ("arbitrum-sepolia" | "base-goerli" | "base-sepolia" | "bsc-testnet" | "ethereum-goerli" | "ethereum-sepolia" | "polygon-mumbai" | "polygon-amoy" | "optimism-goerli" | "optimism-sepolia" | "zora-goerli" | "zora-sepolia" | "hypersonic-testnet")[];
declare const BlockchainIncludingTestnet: {
    readonly ARBITRUM_SEPOLIA: "arbitrum-sepolia";
    readonly BASE_GOERLI: "base-goerli";
    readonly BASE_SEPOLIA: "base-sepolia";
    readonly BSC_TESTNET: "bsc-testnet";
    readonly ETHEREUM_GOERLI: "ethereum-goerli";
    readonly ETHEREUM_SEPOLIA: "ethereum-sepolia";
    readonly POLYGON_MUMBAI: "polygon-mumbai";
    readonly POLYGON_AMOY: "polygon-amoy";
    readonly OPTIMISM_GOERLI: "optimism-goerli";
    readonly OPTIMISM_SEPOLIA: "optimism-sepolia";
    readonly ZORA_GOERLI: "zora-goerli";
    readonly ZORA_SEPOLIA: "zora-sepolia";
    readonly HYPERSONIC_TESTNET: "hypersonic-testnet";
    readonly ETHEREUM: "ethereum";
    readonly POLYGON: "polygon";
    readonly BSC: "bsc";
    readonly OPTIMISM: "optimism";
    readonly ARBITRUM: "arbitrum";
    readonly BASE: "base";
    readonly ZORA: "zora";
    readonly ARBITRUMNOVA: "arbitrumnova";
    readonly ZKATANA: "zkatana";
    readonly ZKYOTO: "zkyoto";
    readonly ASTAR_ZKEVM: "astar-zkevm";
    readonly APEX: "apex";
    readonly SOLANA: "solana";
    readonly CARDANO: "cardano";
    readonly SUI: "sui";
    readonly APTOS: "aptos";
};
type BlockchainIncludingTestnet = ObjectValues<typeof BlockchainIncludingTestnet>;
declare const BLOCKCHAINS_INCLUDING_TESTNETS: readonly ("ethereum" | "polygon" | "bsc" | "optimism" | "arbitrum" | "base" | "zora" | "arbitrumnova" | "zkatana" | "zkyoto" | "astar-zkevm" | "apex" | "arbitrum-sepolia" | "base-goerli" | "base-sepolia" | "bsc-testnet" | "ethereum-goerli" | "ethereum-sepolia" | "polygon-mumbai" | "polygon-amoy" | "optimism-goerli" | "optimism-sepolia" | "zora-goerli" | "zora-sepolia" | "hypersonic-testnet" | "solana" | "cardano" | "sui" | "aptos")[];

declare function isBlockchain<T extends Blockchain = Blockchain>(value: unknown, expectedBlockchain?: T): value is T;

declare function isBlockchainIncludingTestnets<T extends BlockchainIncludingTestnet = BlockchainIncludingTestnet>(value: unknown, expectedBlockchain?: T): value is T;

declare const BLOCKCHAIN_TO_COPY_NAME: Record<BlockchainIncludingTestnet, string>;
declare function blockchainToDisplayName(blockchain: BlockchainIncludingTestnet): string;

declare const BLOCKCHAIN_TO_CHAIN_ID: Record<EVMBlockchainIncludingTestnet, number>;
declare function blockchainToChainId(blockchain: EVMBlockchainIncludingTestnet): number;

declare const CHAIN_ID_TO_BLOCKCHAIN: Record<number, EVMBlockchainIncludingTestnet>;
declare function chainIdToBlockchain(chainId: number): EVMBlockchainIncludingTestnet | undefined;

declare function isEVMBlockchain(value: unknown): value is EVMBlockchainIncludingTestnet;

export { APIKeyEnvironmentPrefix, type APIKeyPrefix, APIKeyUsageOrigin, APIKeyUsageOriginPrefix, ApiClient, BLOCKCHAINS, BLOCKCHAINS_INCLUDING_TESTNETS, BLOCKCHAIN_BASE_LAYERS, BLOCKCHAIN_TESTNETS, BLOCKCHAIN_TO_CHAIN_ID, BLOCKCHAIN_TO_COPY_NAME, Blockchain, BlockchainBaseLayer, BlockchainIncludingTestnet, BlockchainTestnet, CHAIN_ID_TO_BLOCKCHAIN, CROSSMINT_API_KEY_SIGNER_PUBLICKEY_PROD, CROSSMINT_API_KEY_SIGNER_PUBLICKEY_STAGING, type CardanoNFT, type Crossmint, CrossmintApiClient, type CrossmintApiClientInternalConfig, type CssFontSource, type CustomFontSource, EVMBlockchain, EVMBlockchainIncludingTestnet, EVMBlockchainTestnet, type EVMNFT, EVM_BLOCKCHAINS_INCLUDING_TESTNETS, EVM_BLOCKCHAIN_TESTNETS, EVM_CHAINS, type NFT, type NFTCollectionViewProps, type NFTDetailProps, type NFTLocator, type NFTOrNFTLocator, type ObjectValues, type SolanaNFT, type UIConfig, type UiConfigColors, type UiConfigFonts, type UserIdentifier, type UserIdentifierParams, type ValidateAPIKeyFailResult, type ValidateAPIKeyPrefixExpectations, type ValidateAPIKeyPrefixResult, type ValidateAPIKeyPrefixSuccessData, type ValidateAPIKeyPrefixSuccessResult, type ValidateAPIKeyResult, type ValidateApiKeySuccessData, type ValidateApiKeySuccessResult, type Wallet, blockchainToChainId, blockchainToDisplayName, chainIdToBlockchain, createCrossmint, environmentToCrossmintBaseURL, environmentToExpectedPublicKey, getEnvironmentForKey, isBlockchain, isBlockchainIncludingTestnets, isEVMBlockchain, objectValues, usageOriginToPrefix, validateAPIKey, validateAPIKeyPrefix };
